#ifndef NT2_INCLUDE_FUNCTIONS_IS_SIMD_LOGICAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_SIMD_LOGICAL_HPP_INCLUDED

#include <nt2/reduction/include/functions/is_simd_logical.hpp>

#endif
